<?php

# ***** BEGIN LICENSE BLOCK *****
# This file is part of passCat plugin for DotClear 1.2.3.
# Copyright (c) 2006 Mikal Pirio and contributors. All rights
# reserved.
#
# passCat is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# as published by the Free Software Foundation.
#
# passCat is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with passCat; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# ***** END LICENSE BLOCK *****


passCat_info('==> inc/classes/class.passCat_blog.php');

require_once dirname(__FILE__).'/../../../../../layout/class.xblog.php';


/**
@class passCat_blog

=== Introduction ===

La classe passCat_blog tend la classe xblog qui est encharge de toute la
gestion du blog. Elle ncessite pour fonctionner qu'un objet de type
'''blog''' soit existant ainsi qu'un objet de type '''passCat'''. L'objet
de type '''blog''' permettra d'initialiser les diffrents paramtres.

Cette classe redfinit un certain nombre de mthodes en y insrant la
fonctionnalit de protection par mot de passe des catgories.

@param  array	passCat_Cookie  Ensemble des catgories et mot de passes associs
@param  string	t_passCategorie Nom de la table des mots de passe des catgories
*/

class passCat_blog extends xblog
{
	# le cookie passCat
	var $passCat_Cookie;

	# la table passCat
	var $t_passCategorie;

	# l'objet de type '''passCat'''	
	var $passCat;


	/** @doc
	=== Mthodes gnrales === */

	/**
	@function       passCat_blog

	'''Constructeur'''. Cette mthode initialise l'objet passCat_blog.

	@param  objet   blog            Objet de type blog ou xblog
	@param  objet   passCat		Objet de type passCat
	*/
	function passCat_blog($blog, &$passCat)
	{
		$this->passCat = &$passCat;
	
		passCat_info('passCat_blog::passCat_blog()');

		# initialisation des paramtres passCat_blog  l'aide de
		# de ceux de l'ojet blog
		foreach(get_object_vars($blog) as $key => $val) {
			$this->$key = $val;
			
			# cf http://fr.php.net/manual/fr/language.types.string.php#73524
			if (!is_object($val) || method_exists($val, '__toString')) {
				$string = (string)$val;
			}
			else {
				$string = 'Object';
			}
			
			passCat_info('  + initialisation de '.$key.' avec '.$string);
		}

		$this->t_passCategorie = DB_PREFIX.'passcat';

		$this->passCat_Cookie = array();
		# le cookie existe-t'il ?
		if ( isset($_COOKIE['passcat']) ) {
			# si oui, on rcupre les donnes
			$this->passCat_Cookie = unserialize($_COOKIE['passcat']);
		}
	}

	/* ===================================================
	Billets
	=================================================== */
	/** @doc
	=== Mthodes de gestion des billets === */

	/**
	@function getLastNews
	
	Cette functions renvoie un recordset (ou l'objet dfini par la proprit
	'''rs_blogpost''') contenant les n derniers billets.
	
	$cat peut tre une chane ou un entier selon que l'on souhaite travailler
	avec ''cat_id'' ou ''cat_libelle_url''.
	
	@param	integer	limit		Nombre de rsultats  renvoyer (20)
	@param	mixed	cat			Restreindre  la catgori donne
	@param	string	order		Critre de tri ('post_dt DESC')
	@param	boolean	selected		Uniquement les billets marqus ''post_selected'' (false)
	@param	string	lang			Restreindre  la langue donne
	@return	recordset
	*/
	function getLastNews($limit=20,$cat='',$order='post_dt DESC',$selected=false,$lang='')
	{
		$fnom = 'passCat_blog::getLastNews';

		passCat_info($fnom.'(');
		passCat_info('  $limit    = '.$limit);
		passCat_info('  $cat      = '.$cat);
		passCat_info('  $order    = '.$order);
		passCat_info('  $selected = '.$selected);
		passCat_info('  $lang     = '.$lang);
		passCat_info(')');

		$reqPlus = '';
		
		# si c'est pour une catgorie en particulier
		if ($cat != '') {

			passCat_info($fnom.'  + C\'est pour une catgorie en particulier');
	
			# si on est dj authentifi pour cette catgorie
			if ( $this->OKPassCat($cat) ) {
				
				passCat_info($fnom.'  + OKPassCat('.$cat.') : TRUE');
	
				if (preg_match('/^[0-9]+$/',$cat)) {
					$reqPlus .= 'AND C.cat_id = '.$cat.' ';
				}
				else {
					$reqPlus .= 'AND C.cat_libelle_url = \''.$this->con->escapeStr($cat).'\' ';
				}
			}
			# on est pas authentifi pour cette catgorie
			else {
				passCat_info($fnom.'  + OKPassCat('.$cat.') : FALSE');
				passCat_info($fnom.'      `-> donc $this->passCat->setAuth(true)');

				# on redirige vers l'authentification
				$this->passCat->setAuth(true);
			
				# on ne peut pas renvoyer false car dans le fichier layout/prepend.php
				# la fonction "isEmpty" de l'instance de la classe "recordset" renvoy
				# par notre fonction (getLastNews) est apelle... Cela conduirait  une
				# erreur (d'ailleurs  ce sujet, ce serait certainement quelque chose
				#  corriger dans DotClear !!! Donc on va retourner un recordset vide.
				# return false;
				return new $this->rs_blogpost(array());
			}
		}
		# si c'est pour toutes les catgories, on ne va afficher
		# que les news des catgories authorises
		else {
			passCat_info($fnom.'  + C\'est pour toutes les catgories');

			#recupre la liste des catgories protges
			$req = 'SELECT cat_id FROM '.$this->t_passCategorie;
			if( ($liste=$this->con->select($req)) == false ) {
				$this->setError('MySQL : '.$this->con->error(),2000);
				trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
				
				# remarque idem cf plus haut
				#return false;
				return new $this->rs_blogpost(array());
			}
			
			while( $liste->fetch() ){

				$cat_id = $liste->f(0);

				passCat_info($fnom.'  + $cat_id = '.$cat_id);

				if (!$this->OKPassCat($cat_id)) {
					passCat_info($fnom.'      `-> OKPassCat('.$cat_id.') : FALSE');
					$reqPlus .= 'AND C.cat_id != '.$cat_id.' ';
				}

			}
		}
		
		if ($selected) {
			$reqPlus .= 'AND P.post_selected = 1 ';
		}
		
		if ($lang != '') {
			$reqPlus .= 'AND P.post_lang = \''.$this->con->escapeStr($lang).'\' ';
		}
		
		$strReq = $this->SQL($reqPlus,$order,$limit);
		
		if (($rs = $this->con->select($strReq,$this->rs_blogpost)) !== false) {
			$rs->setBlog($this);
			return $rs;
		} else {
			$this->setError('MySQL : '.$this->con->error(),2000);
			trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);

			# remarque idem. cf plus haut...
			#return false;
			return new $this->rs_blogpost(array());
		}
	}
	
	/**
	@function getPostByID
	
	Slection d'un billet par son ID. Cette mthode renvoie un recordset
	tendu (comme la prcdente) contenant le billet slectionn.
	
	@param	integer	id		ID du billet
	@return	recordset
	*/
	function getPostByID($id)
	{
		$fnom = 'passCat_blog::getPostByID';

		passCat_info($fnom.'('.$id.')');

		$reqPlus = 'AND post_id = '.(integer) $id.' ';
		
		# rcuprer le cat_id  l'aide de l'id du post
		$req = 'SELECT cat_id FROM '.$this->t_post.' '.
			'WHERE post_id = '.(integer) $id;


		if ( ($result = $this->con->select($req)) == false ) {
			$this->setError('MySQL : '.$this->con->error(),2000);
			trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
			return false;
		}
		else {
			# si on est pas autoris pour cette catgorie
			if( !$this->OKPassCat($result->f(0)) ){
				passCat_info($fnom.' : OKPassCat=false');
				passCat_info($fnom.'  `-> donc on va rediriger');
				# dans la requete, P correspond  dc_post
				# de cette faon, on devrait renvoyer un recordset vide :)
				$reqPlus .= 'AND P.cat_id != '.$result->f(0).' ';
				# et normalement on redirige vers l'authentification
				$this->passCat->setAuth(true);
			}
		}

		$strReq = $this->SQL($reqPlus);
		
		if (($rs = $this->con->select($strReq,$this->rs_blogpost)) !== false) {
			$rs->setBlog($this);
			return $rs;
		} else {
			$this->setError('MySQL : '.$this->con->error(),2000);
			trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
			return false;
		}
	}
	
	/**
	@function getPostByDate
	
	Slection de billet par une date. Les paramtre de mois et d'anne sont
	obligatoire. Les aures optionnels. La catgorie peut tre une chane ou
	un entier.
	
	La mthode renvoie un recordset tendu.
	
	@param	integer	y		Anne
	@param	integer	m		Mois
	@param	integer	d		Jour ('')
	@param	mixed	cat		Restreindre  la catgori donne
	@param	string	order		Critre de tri ('post_dt DESC')
	@param	boolean	selected	Uniquement les billets marqus ''post_selected'' (false)
	@param	string	lang		Restreindre  la langue donne
	@param  mixed   limit		pour le plugin Pagination... Par rapport  ce dernier
					j'ai mis le paramtre  la fin avec une valeur par pas dranger
					qd elle sera appel sans le paramtre limit
	@return	recordset
	*/
	function getPostByDate($y,$m,$d='',$cat='',$order='post_dt DESC',$selected=false,$lang='',$limit='')
	{
		$fnom = 'passCat_blog::getPostByDate';

		passCat_info($fnom.'(');
		passCat_info('  $y        = '.$y);
		passCat_info('  $m        = '.$m);
		passCat_info('  $d        = '.$d);
		passCat_info('  $cat      = '.$cat);
		passCat_info('  $order    = '.$order);
		passCat_info('  $selected = '.$selected);
		passCat_info('  $lang     = '.$lang);
		passCat_info('  $limit    = '.$limit);
		passCat_info(')');


		$reqPlus = 'AND DATE_FORMAT(post_dt,\'%Y\') = \''.(integer) $y.'\' ';
		$reqPlus .= 'AND DATE_FORMAT(post_dt,\'%c\') = \''.(integer) $m.'\' ';
		
		if ($d != '') {
			$reqPlus .= 'AND DATE_FORMAT(post_dt,\'%e\') = \''.(integer) $d.'\' ';
		}
		
		if ($cat != '') {

			# si on est autoris pour cette catgorie
			if ($this->OKPassCat($cat)) {
		/*		$str = '=';
			}
			else {
				$str = '!=';
			}

			# grce  la var $str on ajoute soit = (autoris) ou != (pas autoris)
			if (preg_match('/^[0-9]+$/',$cat)) {
				$reqPlus .= 'AND C.cat_id '.$str.' '.$cat.' ';
			} else {
				$reqPlus .= 'AND C.cat_libelle_url '.$str.' \''.$this->con->escapeStr($cat).'\' ';
		*/

				if (preg_match('/^[0-9]+$/',$cat)) {
					$reqPlus .= 'AND C.cat_id = '.$cat.' ';
				}
				 else {
					$reqPlus .= 'AND C.cat_libelle_url =  \''.$this->con->escapeStr($cat).'\' ';
				}
			}
			else {
				# pas autoris
				$this->passCat->setAuth(true);
				return new $this->rs_blogpost(array());
			}

		}
		else {
			# si $cat est vide
			#recupre la liste des catgories protges
			$req = 'SELECT cat_id FROM '.$this->t_passCategorie;
			if( ($liste=$this->con->select($req)) == false ) {
				$this->setError('MySQL : '.$this->con->error(),2000);
				trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
				return false;
			}

			while( $liste->fetch() ){

				$cat_id = $liste->f(0);

				if (!$this->OKPassCat($cat_id)) {
					$reqPlus .= 'AND C.cat_id != '.$cat_id.' ';
					passCat_info($fnom.' + enlve les posts de la catgorie '.$cat_id);
				}

			}

		}
		
		if ($selected) {
			$reqPlus .= 'AND P.post_selected = 1 ';
		}
		
		if ($lang != '') {
			$reqPlus .= 'AND P.post_lang = \''.$this->con->escapeStr($lang).'\' ';
		}
		
		$strReq = $this->SQL($reqPlus,$order,$limit);
		
		if (($rs = $this->con->select($strReq,$this->rs_blogpost)) !== false) {
			$rs->setBlog($this);
			return $rs;
		} else {
			$this->setError('MySQL : '.$this->con->error(),2000);
			trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
			return false;
		}
	}
	
	/**
	@function searchPost
	
	Recherche d'un billet selon des mots cl et renvoie un recordset tendu. La
	recherche est faite sur les champs ''post_content'', ''post_titre'' et
	''post_chapo''.
	
	@param	string	w			Mots cl
	@return	recordset
	*/
	function searchPost($w)
	{
		$fnom = 'passCat_blog::searchPost';

		passCat_info($fnom.'('.$w.')');

		$strip = array('+',')','(',',','\'');
		$w = strtolower($w);
		$w = str_replace($strip,' ',$w);
		$w = preg_replace('/( )+/',' ',$w);
		
		$reqPlus = '';
		foreach(explode(' ',$w) as $v)
		{
			$reqPlus .= 'AND (LOWER(post_content) LIKE \'%'.$this->con->escapeStr($v).'%\' OR '.
			'LOWER(post_titre) LIKE \'%'.$this->con->escapeStr($v).'%\' OR '.
			'LOWER(post_chapo) LIKE \'%'.$this->con->escapeStr($v).'%\') ';
		}
		
		#recupre la liste des catgories protges
		$req = 'SELECT cat_id FROM '.$this->t_passCategorie;
		if( ($liste=$this->con->select($req)) == false ) {
			$this->setError('MySQL : '.$this->con->error(),2000);
			trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
			return false;
		}

		# pour toutes les catgories protges
		while( $liste->fetch() ){

			# on rcupre le cat_id de la catgorie protge courante
			$cat_id = $liste->f(0);

			# si elle n'est pas autorise
			if (!$this->OKPassCat($cat_id)) {
				# on l'exclue
				$reqPlus .= 'AND C.cat_id != '.$cat_id.' ';
			}

		}
		
		$strReq = $this->SQL($reqPlus,'post_dt DESC');
		
		if (($rs = $this->con->select($strReq,$this->rs_blogpost)) !== false) {
			$rs->setBlog($this);
			return $rs;
		} else {
			$this->setError('MySQL : '.$this->con->error(),2000);
			trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
			return false;
		}
	}
	


	/**
	@function getAllDates

	Obtenir les dates (jours ou mois) du blog. Cette mthode renvoie un
	tableau contenant toutes les dates du blog. On peut restreindre la
	recherche  une anne, un mois (d'une anne donne) ou un jour.

	Le critre de catgorie peut tre une chane ou un entier.

	La tableau renvoy est un tableau de plusieurs lignes dont la cl est
	un timestamp et la valeur la date au format YYYY-MM-DD.

	@param  string  type	            Type de date ; y, d ou m
	@param  integer y                       Anne ('')
	@param  integer m                       Mois ('')
	@param  integer d                       Jour ('')
	@param  mixed   cat                     Restreindre  la catgori donne ('')
	@return array
        */
        function getAllDates($type='m',$y='',$m='',$d='',$cat='')
        {
		if ($type == 'y') {
			$dt_f = '%Y-01-01';
		} elseif ($type == 'd') {
			$dt_f = '%Y%-%m-%d';
		} else {
			$dt_f = '%Y-%m-01';
		}

		$reqPlus = '';

		if ($this->pub_mode !== NULL) {
			$reqPlus .= 'AND post_pub = '.$this->pub_mode.' ';
		}

		if ($this->lang !== NULL) {
			$reqPlus .= 'AND post_lang = \''.$this->con->escapeStr($this->lang).'\' ';
		}

		if ($this->user_id != '') {
			$reqPlus .= 'AND P.user_id = \''.$this->con->escapeStr($this->user_id).'\' ';
		}

		if ($y != '') {
			$reqPlus .= 'AND DATE_FORMAT(post_dt,\'%Y\') = \''.(integer) $y.'\' ';
		}

		if ($m != '') {
			$reqPlus .= 'AND DATE_FORMAT(post_dt,\'%c\') = \''.(integer) $m.'\' ';
		}

		if ($d != '') {
			$reqPlus .= 'AND DATE_FORMAT(post_dt,\'%e\') = \''.(integer) $d.'\' ';
		}

		if ($cat != '') {

			# si la catgori est autorise
			if ($this->OKPassCat($cat)) {
				$str = '=';
			}
			else {
				$str = '!=';
			}

			if (preg_match('/^[0-9]+$/',$cat)) {
				$reqPlus .= 'AND C.cat_id '.$str.' '.$cat.' ';
			} else {
				$reqPlus .= 'AND C.cat_libelle_url '.$str.' \''.$this->con->escapeStr($cat).'\' ';
			}
		}
		else {
			# si $cat est vide
			#recupre la liste des catgories protges
			$req = 'SELECT cat_id FROM '.$this->t_passCategorie;
			if( ($liste=$this->con->select($req)) == false ) {
				$this->setError('MySQL : '.$this->con->error(),2000);
				trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
				return false;
			}

			while( $liste->fetch() ){

				$cat_id = $liste->f(0);

				if (!$this->OKPassCat($cat_id)) {
					$reqPlus .= 'AND C.cat_id != '.$cat_id.' ';
				}

			}
		}

		$strReq = 'SELECT DISTINCT(DATE_FORMAT(post_dt,\''.$dt_f.'\')) '.
			        'FROM '.$this->t_post.' P, '.$this->t_categorie.' C '.
			        'WHERE P.cat_id = C.cat_id '.
			        $reqPlus.
			        'ORDER BY post_dt DESC ';

		if (($rs = $this->con->select($strReq)) === false) {
			echo $this->con->error();
			$this->setError('MySQL : '.$this->con->error(),2000);
			return false;
		} else {
			$res = array();
			while(!$rs->EOF()) {
				$res[strtotime($rs->field(0))] = $rs->field(0);
				$rs->moveNext();
			}
			return $res;
		}
	}

	/**
	@function getEarlierDate

	Renvoie la date au format standard du billet le plus rcent ou false en cas
	d'erreur. $cat peut tre une chane ou un entier.

	@param  mixed   cat                     Identifiant de la catgorie
	@return string
	*/
	function getEarlierDate($cat='')
	{
		$reqPlus = '';

		if ($cat != '') {

			if ($this->OKPassCat($cat)) {
				$str = '=';
			}
			else {
				$str = '!=';
			}

			if (preg_match('/^[0-9]+$/',$cat)) {
				$reqPlus .= 'AND C.cat_id '.$str.' '.$cat.' ';
			} else {
				$reqPlus .= 'AND C.cat_libelle_url '.$str.' \''.$this->con->escapeStr($cat).'\' ';
			}

		}
		else {
			# si $cat est vide
			#recupre la liste des catgories protges
			$req = 'SELECT cat_id FROM '.$this->t_passCategorie;
			if( ($liste=$this->con->select($req)) == false ) {
				$this->setError('MySQL : '.$this->con->error(),2000);
				trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
				return false;
			}

			while( $liste->fetch() ){

				$cat_id = $liste->f(0);

				if (!$this->OKPassCat($cat_id)) {
					$reqPlus .= 'AND C.cat_id != '.$cat_id.' ';
				}

			}
		}

		if ($this->pub_mode !== NULL) {
			$reqPlus .= 'AND post_pub = '.$this->pub_mode.' ';
		}

		if ($this->lang !== NULL) {
			$reqPlus .= 'AND post_lang = \''.$this->con->escapeStr($this->lang).'\' ';
		}

		if ($this->user_id != '') {
			$reqPlus .= 'AND P.user_id = \''.$this->con->escapeStr($this->user_id).'\' ';
		}

		$strReq = 'SELECT MAX(post_dt) '.
			        'FROM '.$this->t_post.' P, '.$this->t_categorie.' C '.
			        'WHERE P.cat_id = C.cat_id '.
			        $reqPlus;

		if (($rs = $this->con->select($strReq)) !== false) {
			return $rs->field(0);
		} else {
			$this->setError('MySQL : '.$this->con->error(),2000);
			return false;
		}
	}


	/**
	@function getNextID

	Renvoie un recordset contenant l'id, le titre et la date du billet
	suivant le timestamp donn par $ts. $dir prend les valeurs 1 (billet
	suivant) ou 0 (billet prcdent).

	@param  string  ts                      Timestamp du billet
	@param  integer dir                     Direction de recherche
	@return recordset
	*/
	function getNextID($ts,$dir=1)
	{
		$ts = (integer) $ts;

		$reqPlus = '';

		if($dir > 0) {
			$sign = '>';
			$order = 'ASC';
		}
		else {
			$sign = '<';
			$order = 'DESC';
		}

		if ($this->pub_mode !== NULL) {
			$reqPlus .= 'AND post_pub = '.$this->pub_mode.' ';
		}

		if ($this->lang !== NULL) {
			$reqPlus .= 'AND post_lang = \''.$this->con->escapeStr($this->lang).'\' ';
		}

		# on recupre la liste des catgories protges
		$req = 'SELECT cat_id FROM '.$this->t_passCategorie;
		if( ($liste=$this->con->select($req)) == false ) {
			$this->setError('MySQL : '.$this->con->error(),2000);
			trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
			return false;
		}

		while( $liste->fetch() ){
			$cat_id = $liste->f(0);

			if (!$this->OKPassCat($cat_id)) {
				$reqPlus .= 'AND cat_id != '.$cat_id.' ';
			}
		}

		$strReq = 'SELECT post_id, post_titre, post_dt '.
			        'FROM '.$this->t_post.' '.
				'WHERE UNIX_TIMESTAMP(post_dt) '.$sign.' \''.$ts.'\' '.
			        $reqPlus.
			        'ORDER BY post_dt '.$this->con->escapeStr($order).' '.
			        'LIMIT 0,1 ';

		if (($rs = $this->con->select($strReq)) !== false) {
			return $rs;
		} else {
			$this->setError('MySQL : '.$this->con->error(),2000);
			return false;
		}
	}

	/**
	@function getPostLanguages

	Renvoie un recordset contenant toutes les langues du blog, ou false en cas
	d'erreur.

	@return recordset
	*/
	function getPostLanguages()
	{
		$reqPlus = '';
		if ($this->pub_mode !== NULL) {
			$reqPlus .= 'AND post_pub = '.$this->pub_mode.' ';
		}

		#recupre la liste des catgories protges
		$req = 'SELECT cat_id FROM '.$this->t_passCategorie;
		if( ($liste=$this->con->select($req)) == false ) {
			$this->setError('MySQL : '.$this->con->error(),2000);
			trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
			return false;
		}

		while( $liste->fetch() ){
			$cat_id = $liste->f(0);

			if (!$this->OKPassCat($cat_id)) {
				$reqPlus .= 'AND cat_id != '.$cat_id.' ';
			}
		}


		$strReq = 'SELECT DISTINCT(post_lang) '.
			        'FROM '.$this->t_post.' '.
			        'WHERE post_lang <> \'\' '.
			        $reqPlus.' '.
			        'ORDER BY post_lang ASC ';

		if (($rs = $this->con->select($strReq)) !== false) {
			return $rs;
		} else {
			$this->setError('MySQL : '.$this->con->error(),2000);
			return false;
		}
	}

	/* ===================================================
	Commentaires
	=================================================== */
	/** @doc
	=== Mthodes de gestion des commentaires === */

	 /**
	@function getNbComments

	Retourn le nombre de commentaires d'un billet sous forme d'un entier.

	@param  integer id                      ID du billet
	@return integer
	*/
	function getNbComments($id='')
	{
		$reqPlus = '';

		if ($this->pub_mode !== NULL) {
			$reqPlus .=
		        'AND C.comment_pub = '.$this->pub_mode.' '.
		        'AND P.post_pub = '.$this->pub_mode.' ';
		}

		if ($this->user_id != '') {
			$reqPlus .= 'AND P.user_id = \''.$this->con->escapeStr($this->user_id).'\' ';
		}

		if ($id != '') {
			
			# rcupration du cat_id de ce post
			$req = 'SELECT cat_id FROM '.$this->t_post.' WHERE post_id = '.$id;
			if (($r = $this->con->select($req)) !== false) {
				$this->setError('MySQL : '.$this->con->error(),2000);
				return false;
			}

			# si cette catgorie est autorise
			if ($this->OKPassCat($r->f(0))) {
				$reqPlus .= 'AND P.post_id = '.(integer) $id.' ';
			}
			else {
				# sinon on retourne 0 (aucun commentaire... la catgorie n'est pas autorise
				return 0;
			}
		}
		else {
			# on va retirer les catgories protges qui n'ont pas t autorises
			
			#recupre la liste des catgories protges
			$req = 'SELECT cat_id FROM '.$this->t_passCategorie;
			if( ($liste=$this->con->select($req)) == false ) {
				$this->setError('MySQL : '.$this->con->error(),2000);
				trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
				return false;
			}

			while( $liste->fetch() ){

				$cat_id = $liste->f(0);

				if (!$this->OKPassCat($cat_id)) {
					$reqPlus .= 'AND P.cat_id != '.$cat_id.' ';
				}

			}
		}

		$strReq = 'SELECT count(comment_id) '.
			        'FROM '.$this->t_comment.' C, '.$this->t_post.' P '.
			        'WHERE P.post_id = C.post_id '.
			        'AND comment_trackback <> 1 '.
			        $reqPlus;

		if (($rs = $this->con->select($strReq)) !== false) {
			return $rs->field(0);
		} else {
			$this->setError('MySQL : '.$this->con->error(),2000);
			return false;
		}
	}

	/**
	@function getNbTrackbacks

	Retourn le nombre de trackbacks d'un billet sous forme d'un entier.

	@param  integer id                      ID du billet
	@return integer
	*/
	function getNbTrackbacks($id='')
	{
		$reqPlus = '';

		if ($this->pub_mode !== NULL) {
			$reqPlus .=
		        'AND C.comment_pub = '.$this->pub_mode.' '.
		        'AND P.post_pub = '.$this->pub_mode.' ';
		}

		if ($this->user_id != '') {
			$reqPlus .= 'AND P.user_id = \''.$this->con->escapeStr($this->user_id).'\' ';
		}

		if ($id != '') {

			# rcupration du cat_id de ce post
			$req = 'SELECT cat_id FROM '.$this->t_post.' WHERE post_id = '.$id;
			if (($r = $this->con->select($req)) !== false) {
				$this->setError('MySQL : '.$this->con->error(),2000);
				return false;
			}

			# si cette catgorie est autorise
			if ($this->OKPassCat($r->f(0))) {
				$reqPlus .= 'AND P.post_id = '.(integer) $id.' ';
			}
			else {
				return 0;
			}
		}
		else {
			# on va retirer les catgories protges qui n'ont pas t autorises

			#recupre la liste des catgories protges
			$req = 'SELECT cat_id FROM '.$this->t_passCategorie;
			if( ($liste=$this->con->select($req)) == false ) {
				$this->setError('MySQL : '.$this->con->error(),2000);
				trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
				return false;
			}

			while( $liste->fetch() ){

				$cat_id = $liste->f(0);

				if (!$this->OKPassCat($cat_id)) {
					$reqPlus .= 'AND P.cat_id != '.$cat_id.' ';
				}

			}
		}


		$strReq = 'SELECT count(comment_id) '.
			        'FROM '.$this->t_comment.' C, '.$this->t_post.' P '.
			        'WHERE P.post_id = C.post_id '.
			        'AND comment_trackback = 1 '.
			        $reqPlus;

		if (($rs = $this->con->select($strReq)) !== false) {
			return $rs->field(0);
		} else {
			$this->setError('MySQL : '.$this->con->error(),2000);
			return false;
		}
	}


	/**
	@function getComments

	Slection des commentaires et trackbacks d'un billet. Renvoie un recordset
	tendu du type dfini par la proprit '''rs_blogcomment'''. Si la valeur de
	$post_id est vide, tous les commentaires seront renvoys.

	@param  integer post_id         ID du billet ('')
	@param  string  order           Send de l'ordre des commentaires, ASC ou DESC ('ASC')
	@param  integer limit           Nombre de commentaires  slctionner (NULL)
	@return recordset
	*/
	function getComments($post_id='',$order='ASC',$limit=NULL)
	{
		$reqPlus = '';

		if ($this->pub_mode !== NULL) {
			$reqPlus .=
		        'AND C.comment_pub = '.$this->pub_mode.' '.
		        'AND P.post_pub = '.$this->pub_mode.' ';
		}

		if ($this->user_id != '') {
			$reqPlus .= 'AND P.user_id = \''.$this->con->escapeStr($this->user_id).'\' ';
		}

		if ($post_id != '') {
			# rcupration du cat_id de ce post
			$req = 'SELECT cat_id FROM '.$this->t_post.' WHERE post_id = '.$post_id;
			if (($r = $this->con->select($req)) == false) {
				$this->setError('MySQL : '.$this->con->error(),2000);
				trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
				return false;
			}

			# si cette catgorie est autorise
			if ( $this->OKPassCat($r->f(0)) ) {
				$reqPlus .= 'AND C.post_id = '.(integer) $post_id.' ';
			}
			else {
				$reqPlus .= 'AND C.post_id != '.(integer) $post_id.' ';
			}
		}
		else {
			# on va retirer les catgories protges qui n'ont pas t autorises

			#recupre la liste des catgories protges
			$req = 'SELECT cat_id FROM '.$this->t_passCategorie;
			if( ($liste=$this->con->select($req)) == false ) {
				$this->setError('MySQL : '.$this->con->error(),2000);
				trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
				return false;
			}

			while( $liste->fetch() ){

				$cat_id = $liste->f(0);

				if (!$this->OKPassCat($cat_id)) {
					$reqPlus .= 'AND P.cat_id != '.$cat_id.' ';
				}

			}
		}


		$strReq = 'SELECT comment_id, comment_dt, comment_upddt, comment_auteur, '.
			        'comment_email, comment_site, comment_content, comment_trackback, '.
			        'comment_pub, comment_ip, P.post_titre, P.post_titre_url, P.post_id, '.
			        'DATE_FORMAT(P.post_dt,\'%d\') AS postday, '.
			        'DATE_FORMAT(P.post_dt,\'%m\') AS postmonth, '.
			        'DATE_FORMAT(P.post_dt,\'%Y\') AS postyear, '.
			        'DATE_FORMAT(comment_dt,\'%Y%m%d\') AS comment_date '.
			        'FROM '.$this->t_comment.' C, '.$this->t_post.' P '.
			        'WHERE P.post_id = C.post_id '.
			        $reqPlus.
			        'ORDER BY comment_dt '.$this->con->escapeStr($order).' ';

		if ($limit !== NULL) {
			$limit = (preg_match('/^[0-9]+$/',$limit)) ? '0,'.$limit : $limit;
			$strReq .= 'LIMIT '.$limit.' ';
		}

		if (($rs = $this->con->select($strReq,$this->rs_blogcomment)) !== false) {
			$rs->setBlog($this);
			return $rs;
		} else {
			$this->setError('MySQL : '.$this->con->error(),2000);
			return false;
		}
	}

	/**
	@function getComment

	Rcupration d'un commentaire par son ID. Renvoie un recordset tendu.

	@param  integer id                      ID du commentaire
	@return recordset
	*/
	function getComment($id)
	{
		$reqPlus = '';

		if ($this->pub_mode !== NULL) {
			$reqPlus .=
		        'AND C.comment_pub = '.$this->pub_mode.' '.
		        'AND P.post_pub = '.$this->pub_mode.' ';
		}

		if ($this->user_id != '') {
			$reqPlus .= 'AND P.user_id = \''.$this->con->escapeStr($this->user_id).'\' ';
		}

		if ($id != '') {

			# rcupration du cat_id de ce post
			$req = 'SELECT cat_id FROM '.$this->t_post.' P, '.$this->t_comment.' C '.
				'WHERE comment_id = '.$id;
			if (($r = $this->con->select($req)) !== false) {
				$this->setError('MySQL : '.$this->con->error(),2000);
				return false;
			}

			# si cette catgorie n'est pas autorise
			if ($this->OKPassCat($r->f(0))) {
				$reqPlus .= 'AND C.comment_id != '.(integer) $id.' ';
			}
		}
		else {
			# on va retirer les catgories protges qui n'ont pas t autorises

			#recupre la liste des catgories protges
			$req = 'SELECT cat_id FROM '.$this->t_passCategorie;
			if( ($liste=$this->con->select($req)) == false ) {
				$this->setError('MySQL : '.$this->con->error(),2000);
				trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
				return false;
			}

			while( $liste->fetch() ){

				$cat_id = $liste->f(0);

				if (!$this->OKPassCat($cat_id)) {
					$reqPlus .= 'AND P.cat_id != '.$cat_id.' ';
				}

			}
		}

		$strReq = 'SELECT comment_id, comment_dt, comment_upddt, comment_auteur, '.
			        'comment_email, comment_site, comment_content, comment_trackback, '.
			        'comment_pub, comment_ip, P.post_titre, P.post_id, P.user_id,'.
			        'DATE_FORMAT(comment_dt,\'%Y%m%d\') AS comment_date '.
			        'FROM '.$this->t_comment.' C, '.$this->t_post.' P '.
			        'WHERE C.comment_id = '.(integer) $id.' '.
			        'AND C.post_id = P.post_id '.
			        $reqPlus;

		if (($rs = $this->con->select($strReq,$this->rs_blogcomment)) !== false) {
			$rs->setBlog($this);
			return $rs;
		} else {
			$this->setError('MySQL : '.$this->con->error(),2000);
			return false;
		}
	}



	/** @doc
	=== Mthodes concernant la protection par mot de passe
	des catgories. === */

	/**
	@function getNumCatId

	Rcupre la version numrique de l'identifiant cat_id si ce dernier est
	une chaine

	La mthode renvoie le cat_id numrique ou false en cas d'erreur

	@param  mixed cat_id	Identifiant de la catgorie

	@return mixed
	*/
	function getNumCatId($cat_id) {

		passCat_info('passCat_blog::getNumCatId('.$cat_id.')');

		if ($cat_id != '') {
			# si c'est un nombre, on renvoie le nombre
			if (preg_match('/^[0-9]+$/',$cat_id)) {
				return $cat_id;
			}
			else {
				$req = 'SELECT cat_id FROM '.$this->t_categorie.' '.
				       'WHERE cat_libelle_url = \''.$this->con->escapeStr($cat_id).'\'';
			
				if ( ($rs = $this->con->select($req)) == false ){
					$this->setError('MySQL : '.$this->con->error(),2000);
					trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
					return false;
				}
				else {
					return $rs->f(0);
				}
			}
		}
		else {
			return false;
		}
	}

	/**
	@function checkPassCat

	Vrifie l'existence d'un mot de passe pour une catgorie. Le paramtre
	$cat_id peut tre un entier, le champ ''cat_id'' de la table passCat 
	sera alors pris en compte. S'il s'agit d'une chaine, la comparaison sera
	faite sur ''cat_libelle_url'' de la table categorie.

	La mthode renvoie true en cas de succs ou false.

	@param  mixed cat_id          Identifiant de la catgorie

	@return boolean
	*/
	function checkPassCat($cat_id) {

	 	passCat_info('passCat_blog::checkPassCat(\''.$cat_id.'\')');

		if ($cat_id != '') {
			# on rcupre la version numrique
			if ( ($cat_id = $this->getNumCatId($cat_id)) == false ) {
				passCat_info('  + Impossible d\avoir l\'id num de cette catgorie');
				return false;
			}
		}
		else {
			return false;
		}

		$strReq = 'SELECT count(*) FROM '.$this->t_passCategorie.' '.
		          'WHERE cat_id = '.(integer) $this->con->escapeStr($cat_id).' ';
		
		if ( ($rs = $this->con->select($strReq)) == false ) {
			$this->setError('MySQL : '.$this->con->error(),2000);
			trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
			return false;
		}
		else {
			if ($rs->field(0) == '0') {
				return false;
			}
			else {
				return true;
			}
		}
	}
	
	/**
	@function getPassCat
	
	Donne le mot de passe de la catgorie. La paramtre $cat_id peut tre
	un entier, le champ ''cat_id'' de la table passCat sera alors pris en compte.
	S'il s'agit	d'une chaine, la comparaison sera faite sur ''cat_libelle_url''
	de la table categorie.
	
	La mthode renvoie le mot de passe ou false en cas d'erreur.
	
	@param	mixed	cat_id		Identifiant de la catgorie
	@return mixed	
	*/
	function getPassCat($cat_id) {

		passCat_info('passCat_blog::getPassCat('.$cat_id.')');

		$result = '';

		if ($cat_id != '') {
			if ( ($cat_id = $this->getNumCatId($cat_id)) == false) {
				return false;
			}
		}
		else {
			# si cat_id est vide
			return false;
		}
		
		$strReq = 'SELECT cat_passwd FROM '.$this->t_passCategorie.' '.
				'WHERE cat_id = \''.$cat_id.'\' ';
		
		if ( ($rs =$this->con->select($strReq)) !== false ) {
			$result = $rs->f('cat_passwd');
		}
		else {
			$this->setError('MySQL : '.$this->con->error(),2000);
			trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
			return false;
		}

		return $result;
	}
	
	/**
	@function addPassCat

	Ajout d'un mot de passe pour une catgorie. Renvoie vrai en cas de succs.

	@param  string  libelle         Libell de la catgorie
	@param  string  pass            mot de passe de la catgorie
	@return boolean
	*/
	function addPassCat($libelle,$pass) {

		passCat_info('passCat_blog::addPassCat('.$libelle.','.$pass.')');
		
		$cat_id='';

		$libelle = trim($libelle);
		$pass = trim($pass);

		if ($libelle == '') {
			$this->setError(__('Empty category title'),1000);
		}

		if ($this->error() !== false) {
			return false;
		}

		#rcupre cat_id
		$req = 'SELECT cat_id FROM '.$this->t_categorie.' '.
			'WHERE cat_libelle = \''.$libelle.'\' ';

		if ( ($rs = $this->con->select($req)) == false) {
    			$this->setError('MySQL : '.$this->con->error(),2000);
			trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
    			return false;
			# si on a plus d'une ligne ou pas du tout...
    		}
    		elseif ( ($rs->nbRow() == 0) or ($rs->nbRow() > 1) ) {
			$this->setError('PASSCAT : 0 or >1 lines...',4000);
			return false;
		}
		# ok, on rcupre l'id
		else {
			$cat_id = $rs->f('cat_id');
		}

		# Le mot de passe est enregistrer en clair... Il faudra penser
		#  le placer en md5 :)
		$insReq = 'INSERT INTO '.$this->t_passCategorie.' '.
    				'(cat_id,cat_passwd) VALUES ('.
				'\''.$cat_id.'\','.
				'\''.$this->con->escapeStr($pass).'\''.
				') ';

		if (!$this->con->execute($insReq)) {
			$this->setError('MySQL : '.$this->con->error(),2000);
			trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
			return false;
		}
		else {
			$this->triggerMassUpd();
			$this->tiggerLog('passCat',$cat_id,'Create password \''.$pass.'\' for categorie '.$cat_id);
			return true;
		}
	}
	
	/**
	@function updPassCat
	
	Modification du mot de passe d'un catgorie. Renvoie vrai en cas de succs.
	
	@param	integer	cat_id		ID de la catgorie  modifier
	@param	string	pass		Mot de passe de la catgorie
	@return	boolean
	*/
	function updPassCat($cat_id,$pass) {
		
		$pass = trim($pass);
		passCat_info('passCat_blog::updPassCat('.$cat_id.', '.$pass.')');
		
		if ($pass == '') {
			$this->setError('Empty category password',1000);
			passCat_info('  ! Empty category password');
			return false;
		}
	/*	
		if (!$this->checkPassCat($cat_id)) {
			error_log('updPassCat : Password for this category does not exist');
			$this->setError('Passord for this category does not exist',2005);
		}
	*/
		if (!$this->checkPassCat($cat_id)) {
			$insReq = 'INSERT INTO '.$this->t_passCategorie.' '.
			        '(cat_id,cat_passwd) VALUES ('.
			        '\''.$cat_id.'\','.
			        '\''.$this->con->escapeStr($pass).'\''.
			        ') ';

			if (!$this->con->execute($insReq)) {
				$this->setError('MySQL : '.$this->con->error(),2000);
				trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
				return false;
			}
			else {
				$this->triggerMassUpd();
				$this->tiggerLog('passCat',$cat_id,'Create password \''.$pass.'\' for categorie '.$cat_id);
				return true;
			}
		}
		else {
	
			# le mot de passe est plac en clair.  voir pr le md5
			$updReq = 'UPDATE '.$this->t_passCategorie.' SET '.
				'cat_passwd = \''.$pass.'\' '.
				'WHERE cat_id = '.$this->con->escapeStr($cat_id).' ';
		
			if (!$this->con->execute($updReq)) {
				$this->setError('MySQL : '.$this->con->error(),2000);
				trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
				return false;
			}
			else {
				$this->triggerMassUpd();
				$this->tiggerLog('passCat',$cat_id,'Update Password to \''.$pass.'\' for category '.$cat_id);
				return true;
			}
		}
	}
		
	/**
	@function delPassCat
	
	Suppression du mot de passe d'une catgorie donne. Renvoie vrai en cas de succs.
	
	@param	integer	cat_id		ID de la catgorie
	@return	boolean
	*/
	function delPassCat($cat_id) {

		passCat_info('passCat_blog::delPassCat('.$cat_id.')');
		
		if ($cat_id == '') {
			$this->setError(__('No category ID'),1000);
		}
		
		if ($this->error() !== false) {
			return false;
		}
		
		$delReq = 'DELETE FROM '.$this->t_passCategorie.' '.
				'WHERE cat_id = '.$this->con->escapeStr($cat_id).' ';
		
		if (!$this->con->execute($delReq)) {
			$this->setError('MySQL : '.$this->con->error(),2000);
			trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
			return false;
		}
		else {
			$this->triggerMassUpd();
			$this->tiggerLog('passCat',$cat_id,'Remove Password for category '.$cat_id);
			return true;
		}
	}
	
	/**
	@function OKPassCat
	
	Vrifie si l'utilisateur est autoris  accder  la catgorie $cat_id.
	Le paramtre $cat_id peut tre un entier, le champ ''cat_id'' de la table
	passCat sera alors pris en compte. S'il s'agit	d'une chaine, la comparaison
	sera faite sur ''cat_libelle_url'' de la table categorie.
	
	La vrification s'effectue  l'aide d'un cookie. Si l'utilisateur est l'administrateur
	ou rdacteur avanc, l'accs est autoris.
	
	La mthode renvoie true si autoris ou false dans le cas contraire ou en cas
	d'erreur.
	
	@param	mixed	cat_id		Identifiant de la catgorie
	@return	boolean
	*/
		
	function OKPassCat($cat_id) {

		$authorized = false;
		
		# si on a  faire  une authentification HTTP et si celle-ci
		# s'est bien passe, alors tout est OK, on passe :D
		if($this->passCat->HTTP_auth && $this->passCat->HTTP_auth_OK) return true;

		# si administrateur ou rdacteur avanc (level >= 5), return true
		$level = 5;

		passCat_info('passCat_blog::OKPassCat('.$cat_id.')');

		if (empty($_SESSION['sess_user_id'])) {
			if (!empty($_COOKIE['dc_admin'])) {
				$cookie = unserialize($_COOKIE['dc_admin']);
				$authorized = $this->checkUser($cookie['user_id'],$cookie['user_pwd'],$level,false);
			}
		}
		else {
			$authorized = $this->checkUser($_SESSION['sess_user_id'],NULL,$level);
		}

		if ($authorized) {
			return true;
		}


		if ($cat_id != '') {
			# on rcupre la version numrique
			if ( ($cat_id = $this->getNumCatId($cat_id)) == false ) {
				return false;
			}
		}
		else {
			return false;
		}
		
		
		# La catgorie est-elle protge ?
		if ( $this->checkPassCat($cat_id) ) {

			passCat_info('  + La catgorie '.$cat_id.' est protge');
	
			# Est-elle prsente dans notre cookie ?
			if ( array_key_exists($cat_id, $this->passCat_Cookie) ) {
				
				passCat_info('  + La catgorie '.$cat_id.' est dans le cookie passCat');

				# si oui, on rcupre son mot de passe dans la table passCat
				if ( ($passCat_passwd = $this->getPassCat($cat_id)) == false ) {
					$this->setError('getPassCat : Impossible de rcuprer le mot de passe',2000);
					passCat_info('getPassCat : Impossible de rcuprer le mot de passe');
					return false;
				}

				passCat_info('  + Le mot de passe de '.$cat_id.' est : '.$passCat_passwd);
	
				# et on compare (le mot de passe ds le cookie est en md5 tandis que dans la base
				# il est en clair.
				if ( $this->passCat_Cookie[$cat_id] == md5($passCat_passwd) ) {
					passCat_info('  + Les 2 mots de passe sont identiques : return true');
					return true;
				}
				else {
					passCat_info('  + Les 2 mots de passe ne correspondent pas : return false');
					return false;
				}
			}
			else {
				passCat_info('  + Aucune entre dans le cookie, faut authentifier...');
				#aucune entre dans le cookie, faut authentifier...
				return false;
			}
		}
		else {
			passCat_info('  + La categorie n\'est pas protge : return true');
			# la categorie n'est pas protge
			# on renvoie true car si la catgorie n'est pas protge on peut qd mme la voir...
			return true;
		}
	}

	/** @doc
	 === Mthodes pour compter les posts : requis par le plugin Pagination. === 
	*/

	/**
	 @function countSQL

	 @param string  reqPlus

	 @return        string
	*/
	function countSQL($reqPlus='')
	{
		$strReq = 'SELECT COUNT(post_id) '.
		        'FROM '.$this->t_post.' P, '.$this->t_categorie.' C '.
		        'WHERE P.cat_id = C.cat_id '.
		        'AND post_pub = 1 '.
		        $reqPlus.' ';

		return($strReq);
	}


	 /**
	 @function countLastNews

	 @param string  cat
	 @param string  lang

	 @return        integer
	 */
	function countLastNews($cat='',$lang='')
	{
		passCat_info('passCat_blog::countLastNews($cat='.$cat.',$lang='.$lang.')');

		$reqPlus = '';

		# pour une catgorie en particulier
		if ($cat != '') {
			if ( $this->OKPassCat($cat) ) {
				if (preg_match('/^[0-9]+$/',$cat)) {
					$reqPlus .= 'AND C.cat_id = '.$cat.' ';
				} else {
					$reqPlus .= 'AND C.cat_libelle_url = \''.$this->con->escapeStr($cat).'\' ';
				}
			}
			else {
				# pas authentifi pour cette catgorie, on retourn donc 0
				return 0;
			}
		}
		# c'est pour toutes les catgories
		else {
			#recupre la liste des catgories protges
			$req = 'SELECT cat_id FROM '.$this->t_passCategorie;
			if( ($liste=$this->con->select($req)) == false ) {
				$this->setError('MySQL : '.$this->con->error(),2000);
				trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
				return false;
			}

			while( $liste->fetch() ){

				$cat_id = $liste->f(0);

				if (!$this->OKPassCat($cat_id)) {
					$reqPlus .= 'AND C.cat_id != '.$cat_id.' ';
				}
			}
		}

		if ($lang != '') {
			$reqPlus .= 'AND P.post_lang = \''.$this->con->escapeStr($lang).'\' ';
		}

		$strReq = $this->countSQL($reqPlus);

		if (($rs = $this->con->select($strReq)) !== false) {
			passCat_info('passCat_blog::countLastNews renvoie '.(integer)$rs->f(0));
			return((integer)$rs->f(0));
		} else {
			return false;
		}
	}

	/**
	 @function countPostByDate

	 @param string  y
	 @param string  m
	 @param string  d
	 @param string  cat
	 @param string  lang

	 @return        integer
	 */
	function countPostByDate($y,$m,$d='',$cat='',$lang='')
	{

		passCat_info('passCat_blog::countPostByDate($y='.$y.',$m='.$m.',$d='.$d.',$cat='.$cat.',$lang='.$lang.')');

		$reqPlus = 'AND DATE_FORMAT(post_dt,\'%Y\') = \''.(integer) $y.'\' ';
		$reqPlus .= 'AND DATE_FORMAT(post_dt,\'%c\') = \''.(integer) $m.'\' ';

		if ($d != '') {
			$reqPlus .= 'AND DATE_FORMAT(post_dt,\'%e\') = \''.(integer) $d.'\' ';
		}

		if ($cat != '') {
			if ($this->OKPassCat($cat)) {
				if (preg_match('/^[0-9]+$/',$cat)) {
					$reqPlus .= 'AND C.cat_id = '.$cat.' ';
				} else {
					$reqPlus .= 'AND C.cat_libelle_url = \''.$this->con->escapeStr($cat).'\' ';
				}
			}
			else {
				return 0;
			}
		}
		else {
			# si $cat est vide
			#recupre la liste des catgories protges
			$req = 'SELECT cat_id FROM '.$this->t_passCategorie;
			if( ($liste=$this->con->select($req)) == false ) {
				$this->setError('MySQL : '.$this->con->error(),2000);
				trigger_error('  ! MySQL : '.$this->con->error(), E_USER_ERROR);
				return false;
			}

			while( $liste->fetch() ){

				$cat_id = $liste->f(0);

				if (!$this->OKPassCat($cat_id)) {
					$reqPlus .= 'AND C.cat_id != '.$cat_id.' ';
				}

			}
		}

		if ($lang != '') {
			$reqPlus .= 'AND P.post_lang = \''.$this->con->escapeStr($lang).'\' ';
		}

		$strReq = $this->countSQL($reqPlus);

		if (($rs = $this->con->select($strReq)) !== false) {
			passCat_info('passCat_blog::CountPostByDate renvoie '.(integer)$rs->f(0));
			return((integer)$rs->f(0));
		} else {
			return false;
		}
	}



}

passCat_info('<== inc/classes/class.passCat_blog.php');

?>
