<?php

# ***** BEGIN LICENSE BLOCK *****
# This file is part of passCat plugin for DotClear 1.2.3.
# Copyright (c) 2006 Mikal Pirio and contributors. All rights
# reserved.
#
# passCat is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# as published by the Free Software Foundation.
#
# passCat is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with passCat; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# ***** END LICENSE BLOCK *****


require_once dirname(__FILE__).'/../../../../../inc/libs/lib.files.php';

/**
* Error Handling Class
*/
class passcat_error {

	var $error_log_filename;
	var $turn;
	var $maxSize;
	var $nbFiles;

	function passcat_error() {
		if ( defined('PASSCAT_DEBUG') && PASSCAT_DEBUG == true ) {

			$dir = DC_SHARE_DIR.'/passCat';
			if ( !file_exists($dir) ) files::makeDir($dir);

			if (defined('PASSCAT_LOGFILE') && PASSCAT_LOGFILE != '') {
				$this->setFilename( $dir.'/'.PASSCAT_LOGFILE );
			}
			else {
				$this->setFilename( $dir.'/passCat.log');
			}

			if (defined('PASSCAT_DEBUG_TURN') && PASSCAT_DEBUG_TURN == 'true') {
				$this->turn = true;
			}
			else {
				$this->turn = false;
			}
	
			if (defined('PASSCAT_DEBUG_MAX') && PASSCAT_DEBUG_MAX != '') {
				$this->setMaxSize(PASSCAT_DEBUG_MAX);
			}
			else {
				$this->setMaxSize(1024);
			}

                        if (defined('PASSCAT_DEBUG_NB') && PASSCAT_DEBUG_NB != '') {
                                $this->setNbFiles(PASSCAT_DEBUG_NB);
                        }
                        else {
                                $this->setNbFiles(7);
                        }

			set_error_handler( array( &$this, 'errorHandler' ) );
			register_shutdown_function( array( &$this, 'errorHandlerDestruct' ) );
		}
	}

	function setFilename( $filename ) {
		$this->error_log_filename = $filename;
	}

	function setMaxSize( $max ) {
		$this->maxSize = $max;
	}

	function setNbFiles( $nb) {
		$this->nbFiles = $nb;
	}

	function gzCompressFile( $source, $level=false, $keep=true ) {
		$dest=$source.'.gz';
		$mode='wb'.$level;
		$error=false;

		if ($fp_out=gzopen($dest,$mode)) {
			if ($fp_in=fopen($source,'rb')) {

				while(!feof($fp_in))
					gzwrite($fp_out,fread($fp_in,1024*512));

				fclose($fp_in);
			}
			else $error=true;

			gzclose($fp_out);
		}
		else $error=true;

		if(!$keep) unlink($source);

		if($error) return false;
		else return $dest;
	}

	function rotateLogFiles($compress=true) {
		$ext = ($compress) ? '.gz' : '';
		$last_logfile = $this->error_log_filename.'.'.($this->nbFiles - 1).$ext;

		# effacement du dernier fichier
		if (file_exists($last_logfile)) {
			unlink($last_logfile);
		}

		for ( $i = $this->nbFiles - 2 ; $i > 0 ; $i-- ) {
			$old = $this->error_log_filename.'.'.$i.$ext;
			$new = $this->error_log_filename.'.'.($i + 1).$ext;

			if( file_exists($old) ) rename($old,$new);
		}

		rename($this->error_log_filename, $this->error_log_filename.'.1');
		if ($compress) $this->gzCompressFile( $this->error_log_filename.'.1','',false);

		touch($this->error_log_filename);
	}

	function errorHandlerDestruct() {
	}

	function errorHandler($error_type, $error_msg, $error_file, $error_line, $error_context) {

		$err = '';
		$tab = '  ';
		$return = false;

		switch ($error_type) {

			case E_ERROR:
			case E_USER_ERROR:
				# ici return = false de faon  ce que s'il y a une erreur
				# le scipt php s'arrte
				$err = $error_file.' - Line '.$error_line.chr(10);
				break;
			case E_WARNING:
			case E_USER_WARNING:
			case E_NOTICE:
			case E_USER_NOTICE:
				# ici return = true de faon  ce que s'il y a une 'erreur'
				# le script php continuera
				# s'il n'y a pas de msg d'erreur
				if ($error_msg == '[PASSCAT_INFO] ') {
					# ligne vide
					$error_msg = '';
				}
				else {
					# sinon on remplace
					$error_msg = str_replace('[PASSCAT_INFO]','[INFO]',$error_msg);
				}
				$return = true;
				break;

		}

		$err .= $tab.$error_msg.chr(10);

		# si on doit tourner les fichiers
		if($this->turn) {
			# on compare la taille du fichier actuel  la taille max
			# si taille sup ou =  max, on compresse et tourne
			$size_octets  = filesize($this->error_log_filename);
			$size_koctets = $size_octets / 1024;
			if($size_koctets >= $this->maxSize) {
				$this->rotateLogFiles();
			}
		}				


		if( $this->error_log_filename == '' ) {
			error_log( $err, 0);
		}
		else {
			error_log( $err, 3, $this->error_log_filename);
		}

		#echo $error_msg,' in ',$error_file,' on line ',$error_line . '<br />';

		return $return;
	}

	function restoreHandler() {
		restore_error_handler();
	}

	function returnHandler() {
		set_error_handler( array( &$this, 'errorHandler' ) );
	}

	function showBacktrace() {
		debug_print_backtrace();
	}

} 

# fonction pour envoyer des infos ds les logs :D
function passCat_info($str=''){
       if ( defined('PASSCAT_DEBUG') && PASSCAT_DEBUG == true ) trigger_error('[PASSCAT_INFO] '.$str, E_USER_NOTICE);
}



?>
